# FileResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**file_id** | **float** |  | 
**name** | **str** |  | 
**created_date** | **datetime** |  | 
**user_created_by** | **str** |  | 
**swa_code** | **str** |  | 
**organisation_name** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

